// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/widgets.dart';
import 'package:wyatt_ui_components/src/core/utils/multi_color.dart';
import 'package:wyatt_ui_components/src/domain/entities/buttons/button_style.dart';

class OutlinedButtonStyle extends ButtonStyle {
  const OutlinedButtonStyle({
    super.radius = 15,
    super.padding = 10,
    super.backgroundColors,
    super.shadow = const BoxShadow(
      blurRadius: 30,
      offset: Offset(0, 5),
      color: Color.fromRGBO(0, 0, 0, 0.05),
    ),
    this.borderColors,
    this.stroke = 2,
  });

  /// Border colors (from left to right).
  final MultiColor? borderColors;

  /// Stroke of the border
  final double? stroke;

  @override
  OutlinedButtonStyle copyWith({
    double? radius,
    double? padding,
    MultiColor? borderColors,
    MultiColor? backgroundColors,
    BoxShadow? shadow,
    double? stroke,
  }) =>
      OutlinedButtonStyle(
        radius: radius ?? this.radius,
        padding: padding ?? this.padding,
        borderColors: borderColors ?? this.borderColors,
        backgroundColors: backgroundColors ?? this.backgroundColors,
        shadow: shadow ?? this.shadow,
        stroke: stroke ?? this.stroke,
      );
}
